RowIndex

Trait RowIndex 

pub trait RowIndex<ColRange> {
    type Target;

    // Required methods
    fn get(this: Self, col: ColRange) -> Self::Target;
    unsafe fn get_unchecked(this: Self, col: ColRange) -> Self::Target;
}
represents a type that can be used to slice a row, such as an index or a range of indices

Required Associated Types

type Target

sliced view type

Required Methods

fn get(this: Self, col: ColRange) -> Self::Target

slice this using col

unsafe fn get_unchecked(this: Self, col: ColRange) -> Self::Target

slice this using col without bound checks

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<'a, 'N, T, Cs: Stride> RowIndex<<Dim<'N> as ShapeIdx>::Idx<usize>> for RowMut<'a, T, Dim<'N>, Cs>

Source

impl<'a, 'N, T, Cs: Stride> RowIndex<<Dim<'N> as ShapeIdx>::Idx<usize>> for RowRef<'a, T, Dim<'N>, Cs>

Source

impl<'a, C: Shape, T, Cs: Stride, ColRange: IntoRange<IdxInc<C>, Len<C>: 'a>> RowIndex<ColRange> for RowMut<'a, T, C, Cs>

Source

type Target = Row<Mut<'a, T, <ColRange as IntoRange<<C as ShapeIdx>::IdxInc<usize>>>::Len<C>, Cs>>

Source

impl<'a, C: Shape, T, Cs: Stride, ColRange: IntoRange<IdxInc<C>, Len<C>: 'a>> RowIndex<ColRange> for RowRef<'a, T, C, Cs>

Source

type Target = Row<Ref<'a, T, <ColRange as IntoRange<<C as ShapeIdx>::IdxInc<usize>>>::Len<C>, Cs>>

Source

impl<'a, T, Cs: Stride> RowIndex<<usize as ShapeIdx>::Idx<usize>> for RowMut<'a, T, usize, Cs>

Source

impl<'a, T, Cs: Stride> RowIndex<<usize as ShapeIdx>::Idx<usize>> for RowRef<'a, T, usize, Cs>